==> editanything-0.0.41.tar.gz: editanything-0.0.41/fastmodel/main.py <==
import pkg_resources
import os
from fastapi import FastAPI
import uvicorn
from fastapi.responses import FileResponse
from starlette.responses import HTMLResponse

from fastmodel.backend.domain.dto.req_classes import SdInpaintReqDto
from fastmodel.backend.util.str_utils import safe_join
from fastmodel.backend.inference.inference import inference_sd_inpaint

CSS_PATH_LIB = pkg_resources.resource_filename("fastmodel", "frontend/edit-anything/assets/css")
IMG_PATH_LIB = pkg_resources.resource_filename("fastmodel", "frontend/edit-anything/assets/img")
JS_PATH_LIB = pkg_resources.resource_filename("fastmodel", "frontend/edit-anything/js")

app = FastAPI()
from fastapi.staticfiles import StaticFiles

app.mount("/static", StaticFiles(directory="fastmodel/frontend"), name="static")

@app.get("/", response_class=HTMLResponse)
async def server():
    file_path = os.path.abspath("fastmodel/frontend/edit-anything/index.html")
    return FileResponse(file_path)


@app.get("/assets/css/{path:path}")
async def build_resource(path: str):
    build_file = safe_join(CSS_PATH_LIB, path)
    return FileResponse(build_file)


@app.get("/js/{path:path}")
async def build_resource(path: str):
    js_file = safe_join(JS_PATH_LIB, path)
    return FileResponse(js_file)


@app.post("/gw/edit-anything/api/v1/bff/sd/inpaint")
async def sd_inpaint(body: SdInpaintReqDto):
    image = body.image
    mask = body.mask
    prompt = body.prompt

    # todo sd in-paint inference
    inpaint_in_base64 = inference_sd_inpaint(image, mask, prompt)
    # todo base64 to image

    return {
        "msg": "ok",
        "msgCode": "10000",
        "success": True,
        "total": 1,
        "data": {
            "imgBase64": inpaint_in_base64,
            "imgUrl": 'https://static.openxlab.org.cn/public/image/aigc_inpaint/7c7288ca-eb10-11ed-86bd-f6d908acfd33.png'
        }
    }


@app.get("/favicon.ico")
async def favicon():
    ico_file = safe_join(IMG_PATH_LIB, 'favicon.ico')
    return FileResponse(ico_file)

def main():
    uvicorn.run(app, host="0.0.0.0", port=9911)

if __name__ == "__main__":
    main()

==> editanything-0.0.42.tar.gz: editanything-0.0.42/fastmodel/main.py <==
import pkg_resources
import os
from fastapi import FastAPI
import uvicorn
from fastapi.responses import FileResponse
from starlette.responses import HTMLResponse

from fastmodel.backend.domain.dto.req_classes import SdInpaintReqDto
from fastmodel.backend.util.str_utils import safe_join
from fastmodel.backend.inference.inference import inference_sd_inpaint

CSS_PATH_LIB = pkg_resources.resource_filename("fastmodel", "frontend/edit-anything/assets/css")
IMG_PATH_LIB = pkg_resources.resource_filename("fastmodel", "frontend/edit-anything/assets/img")
JS_PATH_LIB = pkg_resources.resource_filename("fastmodel", "frontend/edit-anything/js")

app = FastAPI()
from fastapi.staticfiles import StaticFiles

base_dir = os.path.dirname(os.path.abspath(__file__))  # 获取当前脚本所在的目录
static_dir = os.path.join(base_dir, "frontend/edit-anything")  # 静态文件所在的目录
app.mount("/static", StaticFiles(directory=static_dir), name="static")

@app.get("/", response_class=HTMLResponse)
async def server():
    return FileResponse(f"{static_dir}/index.html")


@app.get("/assets/css/{path:path}")
async def build_resource(path: str):
    build_file = safe_join(CSS_PATH_LIB, path)
    return FileResponse(build_file)


@app.get("/js/{path:path}")
async def build_resource(path: str):
    js_file = safe_join(JS_PATH_LIB, path)
    return FileResponse(js_file)


@app.post("/gw/edit-anything/api/v1/bff/sd/inpaint")
async def sd_inpaint(body: SdInpaintReqDto):
    image = body.image
    mask = body.mask
    prompt = body.prompt

    # todo sd in-paint inference
    inpaint_in_base64 = inference_sd_inpaint(image, mask, prompt)
    # todo base64 to image

    return {
        "msg": "ok",
        "msgCode": "10000",
        "success": True,
        "total": 1,
        "data": {
            "imgBase64": inpaint_in_base64,
            "imgUrl": 'https://static.openxlab.org.cn/public/image/aigc_inpaint/7c7288ca-eb10-11ed-86bd-f6d908acfd33.png'
        }
    }


@app.get("/favicon.ico")
async def favicon():
    ico_file = safe_join(IMG_PATH_LIB, 'favicon.ico')
    return FileResponse(ico_file)

def main():
    uvicorn.run(app, host="0.0.0.0", port=9911)

if __name__ == "__main__":
    main()
